import string


class Dolgozat:
    """Egy dolgozat adatait tárolja: fájlnév, név és a kifejezések listája."""
    def __init__(self, fajlnev, nev):
        """Létrehoz egy dolgozat objektumot, és beolvassa
        a megadott nevű fájlból a kifejezéseket."""
        self.fajlnev = fajlnev
        self.nev = nev
        self.kifejezesek = []


def kifejezesek_fajlbol(fajlnev):
    """Beolvassa a megadott nevű fájlból a kifejezéseket, azaz szópárokat.
    Ezek egy mondat egymás melletti szavai, például "ezek egy", "egy mondat",
    "mondat egymás", és így tovább. Rendezett listát ad vissza."""
    elozo = ""
    kifejezesek = []
    with open(fajlnev) as f:
        for sor in f:
            for szo in sor.rstrip("\n").split():
                szo = szo.strip(string.punctuation)
                if szo == "":   # ha csak írásjel lett volna
                    continue
                kifejezesek.append(elozo + " " + szo)
                elozo = szo
    kifejezesek.sort()
    return kifejezesek


def vezerlofajl_beolvas(fajlnev):
    """Végignézi a vezérlőfájlt, és beolvassa az összes dolgozatot,
    amelyet a vezérlőfájl hivatkozik. Előállítja a Dolgozat objektumok
    listáját, és visszatér vele."""
    dolgozatok = []
    with open(fajlnev) as f:
        for egysor in f:
            fajlnev, nev = egysor.rstrip("\n").split(" ", 1)
            dolgozatok.append(Dolgozat(fajlnev, nev))
    return dolgozatok


def dolgozatok_beolvas(dolgozatok):
    """Végigmegy a dolgozatok listáján, és beolvassa mindegyik
    dolgozathoz tartozó szöveget, a szópárok halmazát."""
    for dolgozat in dolgozatok:
        dolgozat.kifejezesek = kifejezesek_fajlbol(dolgozat.fajlnev)
