import dolgozat

class Hasonlosag:
    """Dolgozatok hasonlóságát tárolja: d1 és d2 dolgozat,
    továbbá a has adattag azt, hogy a metszet kifejezései
    mekkora részben d1-ből, vagy d2-ből származnak."""
    def __init__(self, d1, d2):
        self.d1 = d1
        self.d2 = d2
        self.has = halmaz_hasonlosag(d1.kifejezesek, d2.kifejezesek)

    def __str__(self):
        return "{} ({}) <-> {} ({}), {:.4}%".format(
            self.d1.nev, self.d1.fajlnev,
            self.d2.nev, self.d2.fajlnev,
            self.has * 100
        )


def halmaz_hasonlosag(halmaz1, halmaz2):
    """Meghatározza a két kifejezéslista metszetét. Elvárja, hogy a két lista
    rendezve legyen. Részletes magyarázat a programozói dokumentációban."""
    metszet = 0
    i1 = 0
    i2 = 0
    while i1 < len(halmaz1) and i2 < len(halmaz2):
        if halmaz1[i1] < halmaz2[i2]:
            i1 += 1
        elif halmaz1[i1] > halmaz2[i2]:
            i2 += 1
        else:
            i1 += 1
            i2 += 1
            metszet += 1
    # A két hasonlóság közül a nagyobbik, hogy szembetűnőbb legyen.
    return max(metszet / len(halmaz1), metszet / len(halmaz2))


def osszeset_hasonlit(dolgozatok):
    """Összehasonlítja az összes dolgozatpárt, és a Hasonlóság objektumok
    listáját adja vissza. Ebben nem szerepel egy pár kétszer, és a dolgozatok
    magukkal sincsenek összehasonlítva."""
    hasonlosagok = []
    for i in range(0, len(dolgozatok) - 1):
        for j in range(i + 1, len(dolgozatok)):
            hasonlosagok.append(Hasonlosag(dolgozatok[i], dolgozatok[j]))
    return hasonlosagok


def hasonlosag_rendez(hasonlosagok):
    """Csökkenő sorba rendezi a hasonlóság objektumokat,
    azok .has adattagja szerint."""
    def hasonlosag_kulcs(h):
        return -h.has

    hasonlosagok.sort(key=hasonlosag_kulcs)


def hasonlosagok_fajlba(hasonlosagok, fajlnev):
    """Fájlba írja az összes hasonlóságot,
    "hasonlóság;név1;fájlnév1;név2;fájlnév2" formátumban."""
    with open(fajlnev, "w") as f:
        for h in hasonlosagok:
            print("{:.6};{};{};{};{}".format(
                h.has * 100,
                h.d1.nev, h.d1.fajlnev,
                h.d2.nev, h.d2.fajlnev
            ), file=f)


